1.0.0
=====

* Throttling of email sending
* Django 1.8 support
* Admin tweaks and improvements
* Included migrations - for both South and Django 1.7 native migrations.

  Note:

  * If you use South, you will need at least South 1.0
  * You will need to use '--fake' or '--fake-initial' on existing installations.

* Various other fixes, especially from Renato Alves <alves.rjc@gmail.com> - thank you!

0.1.0
=====

* First PyPI version
